@@ -34,50 +34,6 @@
 
 namespace dcpp {
 
-class FinishedItem
-{
-public:
-	enum {
-		COLUMN_FIRST,
-		COLUMN_FILE = COLUMN_FIRST,
-		COLUMN_DONE,
-		COLUMN_PATH,
-		COLUMN_NICK,
-		COLUMN_HUB,
-		COLUMN_SIZE,
-		COLUMN_SPEED,
-		COLUMN_TYPE,
-		COLUMN_LAST
-	};
-
-	FinishedItem(string const& aTarget, const HintedUser& aUser,  int64_t aSize, int64_t aSpeed, time_t aTime, const string& aTTH = Util::emptyString) : 
-		target(aTarget), user(aUser), size(aSize), avgSpeed(aSpeed), time(aTime), tth(aTTH)
-	{
-	}
-
-#ifdef _WIN32
-	const tstring getText(uint8_t col) const;
-	static int compareItems(const FinishedItem* a, const FinishedItem* b, uint8_t col) {
-		switch (col) {
-		case COLUMN_SPEED:	return compare(a->getAvgSpeed(), b->getAvgSpeed());
-		case COLUMN_SIZE:	return compare(a->getSize(), b->getSize());
-		default:			return Util::stricmp(a->getText(col).c_str(), b->getText(col).c_str());
-		}
-	}
-#endif
-	int getImageIndex() const;
-
-	GETSET(string, target, Target);
-	GETSET(HintedUser, user, User);
-	GETSET(int64_t, size, Size);
-	GETSET(int64_t, avgSpeed, AvgSpeed);
-	GETSET(time_t, time, Time);
-	GETSET(string, tth, TTH);
-private:
-	friend class FinishedManager;
-
-};
-
 class FinishedManager : public Singleton<FinishedManager>,
 	public Speaker<FinishedManagerListener>, private QueueManagerListener, private UploadManagerListener
 {
@@ -85,7 +41,7 @@ public:
 	const FinishedItemList& lockList() { cs.lock(); return uploads; }
 	void unlockList() { cs.unlock(); }
 
-	void remove(FinishedItemPtr item);
+	void remove(const FinishedItemPtr& item);
 	void removeAll();
 
 private:
