@@ -22,7 +22,9 @@
 #include <api/ConnectivityApi.h>
 
 #include <api/common/Serializer.h>
+#include <api/common/MessageUtils.h>
 
+#include <airdcpp/connectivity/ConnectivityManager.h>
 #include <airdcpp/connection/ConnectionManager.h>
 #include <airdcpp/search/SearchManager.h>
 
@@ -79,19 +81,19 @@ namespace webserver {
 			{ "udp_port", SearchManager::getInstance()->getPort() },
 		});
 
-		return websocketpp::http::status_code::ok;
+		return http_status::ok;
 	}
 
 	api_return ConnectivityApi::handleDetect(ApiRequest&) {
 		ConnectivityManager::getInstance()->detectConnection();
-		return websocketpp::http::status_code::no_content;
+		return http_status::no_content;
 	}
 
-	void ConnectivityApi::on(ConnectivityManagerListener::Message, const string& aMessage) noexcept {
+	void ConnectivityApi::on(ConnectivityManagerListener::Message, const LogMessagePtr& aMessage) noexcept {
 		if (!subscriptionActive("connectivity_detection_message"))
 			return;
 
-		send("connectivity_detection_message", aMessage);
+		send("connectivity_detection_message", MessageUtils::serializeLogMessage(aMessage));
 	}
 
 	void ConnectivityApi::on(ConnectivityManagerListener::Started, bool v6) noexcept {
