@@ -82,10 +82,10 @@ namespace webserver {
 			aRequest.setResponseBody(ExtensionInfo::serializeExtension(ext));
 		} catch (const Exception& e) {
 			aRequest.setResponseErrorStr(e.getError());
-			return websocketpp::http::status_code::bad_request;
+			return http_status::bad_request;
 		}
 
-		return websocketpp::http::status_code::ok;
+		return http_status::ok;
 	}
 
 	api_return ExtensionApi::handleDownloadExtension(ApiRequest& aRequest) {
@@ -101,10 +101,10 @@ namespace webserver {
 
 		if (!em.downloadExtension(installId, url, sha)) {
 			aRequest.setResponseErrorStr("Extension is being download already");
-			return websocketpp::http::status_code::conflict;
+			return http_status::conflict;
 		}
 
-		return websocketpp::http::status_code::no_content;
+		return http_status::no_content;
 	}
 
 	api_return ExtensionApi::handleDeleteSubmodule(ApiRequest& aRequest) {
@@ -117,10 +117,10 @@ namespace webserver {
 			}
 		} catch (const Exception& e) {
 			aRequest.setResponseErrorStr(e.getError());
-			return websocketpp::http::status_code::internal_server_error;
+			return http_status::internal_server_error;
 		}
 
-		return websocketpp::http::status_code::no_content;
+		return http_status::no_content;
 	}
 
 	api_return ExtensionApi::handleGetEngineStatuses(ApiRequest& aRequest) {
@@ -135,7 +135,7 @@ namespace webserver {
 		}
 
 		aRequest.setResponseBody(ret);
-		return websocketpp::http::status_code::ok;
+		return http_status::ok;
 	}
 
 	void ExtensionApi::on(ExtensionManagerListener::ExtensionAdded, const ExtensionPtr& aExtension) noexcept {
