@@ -22,7 +22,7 @@
 
 #include <api/base/ApiModule.h>
 
-#include <airdcpp/typedefs.h>
+#include <airdcpp/core/header/typedefs.h>
 
 namespace webserver {
 	class FilesystemApi : public ApiModule {
