@@ -31,7 +31,7 @@
 
 namespace webserver {
 	HashApi::HashApi(Session* aSession) : 
-		SubscribableApiModule(aSession, Access::SETTINGS_VIEW),
+		SubscribableApiModule(aSession, Access::SHARE_VIEW),
 		timer(getTimer([this] { onTimer(); }, 1000)) 
 	{
 		createSubscriptions({
@@ -45,16 +45,16 @@ namespace webserver {
 
 		HashManager::getInstance()->addListener(this);
 
-		METHOD_HANDLER(Access::SETTINGS_VIEW, METHOD_GET,	(EXACT_PARAM("database_status")),	HashApi::handleGetDbStatus);
-		METHOD_HANDLER(Access::SETTINGS_EDIT, METHOD_POST,	(EXACT_PARAM("optimize_database")),	HashApi::handleOptimize);
+		METHOD_HANDLER(Access::SHARE_VIEW, METHOD_GET,	(EXACT_PARAM("database_status")),	HashApi::handleGetDbStatus);
+		METHOD_HANDLER(Access::SHARE_EDIT, METHOD_POST,	(EXACT_PARAM("optimize_database")),	HashApi::handleOptimize);
 
-		METHOD_HANDLER(Access::SETTINGS_VIEW, METHOD_GET,	(EXACT_PARAM("stats")),				HashApi::handleGetStats);
+		METHOD_HANDLER(Access::SHARE_VIEW, METHOD_GET,	(EXACT_PARAM("stats")),				HashApi::handleGetStats);
 
-		METHOD_HANDLER(Access::SETTINGS_EDIT, METHOD_POST,	(EXACT_PARAM("pause")),				HashApi::handlePause);
-		METHOD_HANDLER(Access::SETTINGS_EDIT, METHOD_POST,	(EXACT_PARAM("resume")),			HashApi::handleResume);
-		METHOD_HANDLER(Access::SETTINGS_EDIT, METHOD_POST,	(EXACT_PARAM("stop")),				HashApi::handleStop);
+		METHOD_HANDLER(Access::SHARE_EDIT, METHOD_POST,	(EXACT_PARAM("pause")),				HashApi::handlePause);
+		METHOD_HANDLER(Access::SHARE_EDIT, METHOD_POST,	(EXACT_PARAM("resume")),			HashApi::handleResume);
+		METHOD_HANDLER(Access::SHARE_EDIT, METHOD_POST,	(EXACT_PARAM("stop")),				HashApi::handleStop);
 
-		METHOD_HANDLER(Access::SETTINGS_EDIT, METHOD_POST,	(EXACT_PARAM("rename_path")),		HashApi::handleRenamePath);
+		METHOD_HANDLER(Access::SHARE_EDIT, METHOD_POST,	(EXACT_PARAM("rename_path")),		HashApi::handleRenamePath);
 
 		timer->start(false);
 	}
@@ -67,23 +67,23 @@ namespace webserver {
 
 	api_return HashApi::handleResume(ApiRequest&) {
 		HashManager::getInstance()->resumeHashing();
-		return websocketpp::http::status_code::no_content;
+		return http_status::no_content;
 	}
 
 	api_return HashApi::handlePause(ApiRequest&) {
 		HashManager::getInstance()->pauseHashing();
-		return websocketpp::http::status_code::no_content;
+		return http_status::no_content;
 	}
 
 	api_return HashApi::handleStop(ApiRequest&) {
 		HashManager::getInstance()->stop();
-		return websocketpp::http::status_code::no_content;
+		return http_status::no_content;
 	}
 
 	api_return HashApi::handleGetStats(ApiRequest& aRequest) {
 		auto stats = HashManager::getInstance()->getStats();
 		aRequest.setResponseBody(serializeHashStatistics(stats));
-		return websocketpp::http::status_code::ok;
+		return http_status::ok;
 	}
 
 	json HashApi::serializeHashStatistics(const HashManager::HashStats& aStats) noexcept {
@@ -185,18 +185,18 @@ namespace webserver {
 
 	api_return HashApi::handleGetDbStatus(ApiRequest& aRequest) {
 		aRequest.setResponseBody(formatDbStatus(HashManager::getInstance()->maintenanceRunning()));
-		return websocketpp::http::status_code::ok;
+		return http_status::ok;
 	}
 
 	api_return HashApi::handleOptimize(ApiRequest& aRequest) {
 		if (HashManager::getInstance()->maintenanceRunning()) {
 			aRequest.setResponseErrorStr("Database maintenance is running already");
-			return websocketpp::http::status_code::bad_request;
+			return http_status::bad_request;
 		}
 
 		auto verify = JsonUtil::getField<bool>("verify", aRequest.getRequestBody());
 		HashManager::getInstance()->startMaintenance(verify);
-		return websocketpp::http::status_code::no_content;
+		return http_status::no_content;
 	}
 
 	api_return HashApi::handleRenamePath(ApiRequest& aRequest) {
@@ -208,9 +208,9 @@ namespace webserver {
 			HashManager::getInstance()->renameFileThrow(oldPath, newPath);
 		} catch (const HashException& e) {
 			aRequest.setResponseErrorStr(e.getError());
-			return websocketpp::http::status_code::bad_request;
+			return http_status::bad_request;
 		}
 
-		return websocketpp::http::status_code::no_content;
+		return http_status::no_content;
 	}
 }
\ No newline at end of file
