@@ -134,6 +134,7 @@ namespace webserver {
 				});
 			}),
 			aResultGetter,
+			this,
 			[](const json& aData, const ActionHookResultGetter<BundleFileAddHookResult>& aResultGetter) {
 				if (aData.is_null()) {
 					return BundleFileAddHookResult();
@@ -162,6 +163,7 @@ namespace webserver {
 				});
 			}),
 			aResultGetter,
+			this,
 			getBundleAddHookDeserializer(session)
 		);
 	}
@@ -188,7 +190,8 @@ namespace webserver {
 					{ "user", Serializer::serializeHintedUser(aUser) },
 				});
 			}),
-			aResultGetter
+			aResultGetter,
+			this
 		);
 	}
 
@@ -197,7 +200,8 @@ namespace webserver {
 			maybeFireHook(HOOK_FILE_FINISHED, WEBCFG(QUEUE_FILE_FINISHED_HOOK_TIMEOUT).num(), [&]() {
 				return Serializer::serializeItem(aFile, QueueFileUtils::propertyHandler);
 			}),
-			aResultGetter
+			aResultGetter,
+			this
 		);
 	}
 
@@ -206,7 +210,8 @@ namespace webserver {
 			maybeFireHook(HOOK_BUNDLE_FINISHED, WEBCFG(QUEUE_BUNDLE_FINISHED_HOOK_TIMEOUT).num(), [&]() {
 				return Serializer::serializeItem(aBundle, QueueBundleUtils::propertyHandler);
 			}),
-			aResultGetter
+			aResultGetter,
+			this
 		);
 	}
 
@@ -236,7 +241,7 @@ namespace webserver {
 			{ "count", removed }
 		});
 
-		return websocketpp::http::status_code::ok;
+		return http_status::ok;
 	}
 
 	api_return QueueApi::handleIsPathQueued(ApiRequest& aRequest) {
@@ -249,7 +254,7 @@ namespace webserver {
 			}) }
 		});
 
-		return websocketpp::http::status_code::ok;
+		return http_status::ok;
 	}
 
 	api_return QueueApi::handleFindDupePaths(ApiRequest& aRequest) {
@@ -267,7 +272,7 @@ namespace webserver {
 		}
 
 		aRequest.setResponseBody(ret);
-		return websocketpp::http::status_code::ok;
+		return http_status::ok;
 	}
 
 	// BUNDLES
@@ -278,7 +283,7 @@ namespace webserver {
 		auto j = Serializer::serializeItemList(start, count, QueueBundleUtils::propertyHandler, getBundleList());
 
 		aRequest.setResponseBody(j);
-		return websocketpp::http::status_code::ok;
+		return http_status::ok;
 	}
 
 	api_return QueueApi::handleRemoveCompletedBundles(ApiRequest& aRequest) {
@@ -287,14 +292,14 @@ namespace webserver {
 		aRequest.setResponseBody({
 			{ "count", removed }
 		});
-		return websocketpp::http::status_code::ok;
+		return http_status::ok;
 	}
 
 	api_return QueueApi::handleBundlePriorities(ApiRequest& aRequest) {
 		auto priority = Deserializer::deserializePriority(aRequest.getRequestBody(), true);
 		QueueManager::getInstance()->setPriority(priority);
 
-		return websocketpp::http::status_code::no_content;
+		return http_status::no_content;
 	}
 
 	api_return QueueApi::handleGetBundle(ApiRequest& aRequest) {
@@ -302,14 +307,14 @@ namespace webserver {
 
 		auto j = Serializer::serializeItem(b, QueueBundleUtils::propertyHandler);
 		aRequest.setResponseBody(j);
-		return websocketpp::http::status_code::ok;
+		return http_status::ok;
 	}
 
 	BundlePtr QueueApi::getBundle(ApiRequest& aRequest) {
 		auto bundleId = aRequest.getTokenParam();
 		auto b = QueueManager::getInstance()->findBundle(bundleId);
 		if (!b) {
-			throw RequestException(websocketpp::http::status_code::not_found, "Bundle " + Util::toString(bundleId) + " was not found");
+			throw RequestException(http_status::not_found, "Bundle " + Util::toString(bundleId) + " was not found");
 		}
 
 		return b;
@@ -321,14 +326,14 @@ namespace webserver {
 
 		if (searches == 0) {
 			aRequest.setResponseErrorStr("No files to search for");
-			return websocketpp::http::status_code::bad_request;
+			return http_status::bad_request;
 		}
 
 		aRequest.setResponseBody({
 			{ "sent", searches },
 		});
 
-		return websocketpp::http::status_code::ok;
+		return http_status::ok;
 	}
 
 	api_return QueueApi::handleGetBundleFiles(ApiRequest& aRequest) {
@@ -345,7 +350,7 @@ namespace webserver {
 		auto j = Serializer::serializeItemList(start, count, QueueFileUtils::propertyHandler, files);
 
 		aRequest.setResponseBody(j);
-		return websocketpp::http::status_code::ok;
+		return http_status::ok;
 	}
 
 	api_return QueueApi::handleGetBundleSources(ApiRequest& aRequest) {
@@ -355,6 +360,7 @@ namespace webserver {
 		auto ret = json::array();
 		for (const auto& s : sources) {
 			ret.push_back({
+				{ "id", s.getUser().user->getCID().toBase32() },
 				{ "user", Serializer::serializeHintedUser(s.getUser()) },
 				{ "last_speed", s.getUser().user->getSpeed() },
 				{ "files", s.files },
@@ -363,7 +369,7 @@ namespace webserver {
 		}
 
 		aRequest.setResponseBody(ret);
-		return websocketpp::http::status_code::ok;
+		return http_status::ok;
 	}
 
 	api_return QueueApi::handleRemoveBundleSource(ApiRequest& aRequest) {
@@ -375,19 +381,19 @@ namespace webserver {
 			{ "count", removed },
 		});
 
-		return websocketpp::http::status_code::ok;
+		return http_status::ok;
 	}
 
 	api_return QueueApi::handleShareBundle(ApiRequest& aRequest) {
 		auto b = getBundle(aRequest);
 		if (b->getStatus() != Bundle::STATUS_VALIDATION_ERROR) {
 			aRequest.setResponseErrorStr("This action can only be performed for bundles that have failed content validation");
-			return websocketpp::http::status_code::precondition_failed;
+			return http_status::precondition_failed;
 		}
 
 		auto skipScan = JsonUtil::getOptionalFieldDefault<bool>("skip_validation", aRequest.getRequestBody(), false);
 		QueueManager::getInstance()->shareBundle(b, skipScan);
-		return websocketpp::http::status_code::no_content;
+		return http_status::no_content;
 	}
 
 	api_return QueueApi::handleAddFileBundle(ApiRequest& aRequest) {
@@ -418,11 +424,11 @@ namespace webserver {
 					0
 				);
 			} catch (const Exception& e) {
-				complete(websocketpp::http::status_code::bad_request, nullptr, ApiRequest::toResponseErrorStr(e.getError()));
+				complete(http_status::bad_request, nullptr, ApiRequest::toResponseErrorStr(e.getError()));
 				return;
 			}
 
-			complete(websocketpp::http::status_code::ok, Serializer::serializeBundleAddInfo(bundleAddInfo), nullptr);
+			complete(http_status::ok, Serializer::serializeBundleAddInfo(bundleAddInfo), nullptr);
 			return;
 		});
 
@@ -473,7 +479,7 @@ namespace webserver {
 					files.push_back(deserializeBundleFileInfo(fileJson));
 				}
 			} catch (const ArgumentException& e) {
-				complete(websocketpp::http::status_code::bad_request, nullptr, e.toJSON());
+				complete(http_status::bad_request, nullptr, e.toJSON());
 				return;
 			}
 
@@ -490,11 +496,11 @@ namespace webserver {
 
 			// Handle results
 			if (!result) {
-				complete(websocketpp::http::status_code::bad_request, nullptr, ApiRequest::toResponseErrorStr(errorMsg));
+				complete(http_status::bad_request, nullptr, ApiRequest::toResponseErrorStr(errorMsg));
 				return;
 			}
 
-			complete(websocketpp::http::status_code::ok, Serializer::serializeDirectoryBundleAddResult(*result, errorMsg), nullptr);
+			complete(http_status::ok, Serializer::serializeDirectoryBundleAddResult(*result, errorMsg), nullptr);
 			return;
 		});
 
@@ -506,7 +512,7 @@ namespace webserver {
 
 		auto b = getBundle(aRequest);
 		QueueManager::getInstance()->removeBundle(b, removeFinished);
-		return websocketpp::http::status_code::no_content;
+		return http_status::no_content;
 	}
 
 	api_return QueueApi::handleBundlePriority(ApiRequest& aRequest) {
@@ -514,18 +520,18 @@ namespace webserver {
 		auto priority = Deserializer::deserializePriority(aRequest.getRequestBody(), true);
 
 		QueueManager::getInstance()->setBundlePriority(b, priority);
-		return websocketpp::http::status_code::no_content;
+		return http_status::no_content;
 	}
 
 	// FILES (COMMON)
 	QueueItemPtr QueueApi::getFile(ApiRequest& aRequest, bool aRequireBundle) {
 		auto q = QueueManager::getInstance()->findFile(aRequest.getTokenParam());
 		if (!q) {
-			throw RequestException(websocketpp::http::status_code::not_found, "File not found");
+			throw RequestException(http_status::not_found, "File not found");
 		}
 
 		if (aRequireBundle && !q->getBundle()) {
-			throw RequestException(websocketpp::http::status_code::bad_request, "This method may only be used for bundle files");
+			throw RequestException(http_status::bad_request, "This method may only be used for bundle files");
 		}
 
 		return q;
@@ -537,7 +543,7 @@ namespace webserver {
 		auto j = Serializer::serializeItem(qi, QueueFileUtils::propertyHandler);
 		aRequest.setResponseBody(j);
 
-		return websocketpp::http::status_code::ok;
+		return http_status::ok;
 	}
 
 	api_return QueueApi::handleGetFilesByTTH(ApiRequest& aRequest) {
@@ -545,7 +551,7 @@ namespace webserver {
 
 		const auto files = QueueManager::getInstance()->findFiles(tth);
 		aRequest.setResponseBody(Serializer::serializeItemList(QueueFileUtils::propertyHandler, files));
-		return websocketpp::http::status_code::ok;
+		return http_status::ok;
 	}
 
 	api_return QueueApi::handleRemoveFile(ApiRequest& aRequest) {
@@ -553,7 +559,7 @@ namespace webserver {
 
 		auto qi = getFile(aRequest, false);
 		QueueManager::getInstance()->removeFile(qi->getTarget(), removeFinished);
-		return websocketpp::http::status_code::no_content;
+		return http_status::no_content;
 	}
 
 	api_return QueueApi::handleAddFileSegment(ApiRequest& aRequest) {
@@ -562,7 +568,7 @@ namespace webserver {
 
 		QueueManager::getInstance()->addDoneSegment(qi, segment);
 
-		return websocketpp::http::status_code::ok;
+		return http_status::ok;
 	}
 
 	api_return QueueApi::handleResetFileSegments(ApiRequest& aRequest) {
@@ -570,12 +576,12 @@ namespace webserver {
 
 		QueueManager::getInstance()->resetDownloadedSegments(qi);
 
-		return websocketpp::http::status_code::ok;
+		return http_status::ok;
 	}
 
 	Segment QueueApi::parseSegment(const QueueItemPtr& qi, ApiRequest& aRequest) {
 		if (!QueueManager::getInstance()->isWaiting(qi)) {
-			throw RequestException(websocketpp::http::status_code::precondition_failed, "Segments can't be modified for running files");
+			throw RequestException(http_status::precondition_failed, "Segments can't be modified for running files");
 		}
 
 		auto segmentStart = aRequest.getSizeParam(SEGMENT_START);
@@ -587,16 +593,16 @@ namespace webserver {
 			auto blockSize = qi->getBlockSize();
 
 			if (s.getStart() % blockSize != 0) {
-				throw RequestException(websocketpp::http::status_code::bad_request, "Segment start must be aligned by " + Util::toString(blockSize));
+				throw RequestException(http_status::bad_request, "Segment start must be aligned by " + Util::toString(blockSize));
 			}
 
 			if (s.getEnd() != qi->getSize()) {
 				if (s.getEnd() > qi->getSize()) {
-					throw RequestException(websocketpp::http::status_code::bad_request, "Segment end is beyond the end of the file");
+					throw RequestException(http_status::bad_request, "Segment end is beyond the end of the file");
 				}
 
 				if (s.getSize() % blockSize != 0) {
-					throw RequestException(websocketpp::http::status_code::bad_request, "Segment size must be aligned by " + Util::toString(blockSize));
+					throw RequestException(http_status::bad_request, "Segment size must be aligned by " + Util::toString(blockSize));
 				}
 			}
 		}
@@ -616,7 +622,7 @@ namespace webserver {
 			{ "running_progress", Serializer::serializeList(downloaded, serializeSegment) },
 			{ "done", Serializer::serializeList(done, serializeSegment) },
 		});
-		return websocketpp::http::status_code::ok;
+		return http_status::ok;
 	}
 
 	json QueueApi::serializeSegment(const Segment& aSegment) noexcept {
@@ -631,13 +637,13 @@ namespace webserver {
 		auto priority = Deserializer::deserializePriority(aRequest.getRequestBody(), true);
 
 		QueueManager::getInstance()->setQIPriority(qi, priority);
-		return websocketpp::http::status_code::no_content;
+		return http_status::no_content;
 	}
 
 	api_return QueueApi::handleSearchFileAlternates(ApiRequest& aRequest) {
 		auto qi = getFile(aRequest, false);
 		QueueManager::getInstance()->searchFileAlternates(qi);
-		return websocketpp::http::status_code::no_content;
+		return http_status::no_content;
 	}
 
 	api_return QueueApi::handleGetFileSources(ApiRequest& aRequest) {
@@ -647,13 +653,14 @@ namespace webserver {
 		auto ret = json::array();
 		for (const auto& s : sources) {
 			ret.push_back({
+				{ "id", s.getUser().user->getCID().toBase32() },
 				{ "user", Serializer::serializeHintedUser(s.getUser()) },
 				{ "last_speed", s.getUser().user->getSpeed() },
 			});
 		}
 
 		aRequest.setResponseBody(ret);
-		return websocketpp::http::status_code::ok;
+		return http_status::ok;
 	}
 
 	api_return QueueApi::handleRemoveFileSource(ApiRequest& aRequest) {
@@ -661,7 +668,7 @@ namespace webserver {
 		auto user = Deserializer::getUser(aRequest.getCIDParam(), false);
 
 		QueueManager::getInstance()->removeFileSource(qi, user, QueueItem::Source::FLAG_REMOVED);
-		return websocketpp::http::status_code::no_content;
+		return http_status::no_content;
 	}
 
 
