@@ -22,7 +22,6 @@
 #include <stdint.h>
 #include <functional>
 #include <memory>
-#include <boost/detail/container_fwd.hpp>
 
 #include <nlohmann/json_fwd.hpp>
 
@@ -64,8 +63,6 @@ namespace webserver {
 	class WebUser;
 	using WebUserPtr = std::shared_ptr<WebUser>;
 	using WebUserList = std::vector<WebUserPtr>;
-
-	using json = nlohmann::json;
 }
 
 #endif // !defined(DCPLUSPLUS_WEBSERVER_FORWARD_H)
