@@ -52,7 +52,7 @@ void Client::run(const dcpp::StartupParams& aStartupParams) {
 
 	if (!asDaemon) {
 		auto wsm = webserver::WebServerManager::getInstance();
-		printf(".\n\n%s running, press ctrl-c to exit...\n\n", shortVersionString.c_str());
+		printf("\n\n%s running, press ctrl-c to exit...\n\n", shortVersionString.c_str());
 		printf("HTTP port: %d, HTTPS port: %d\n", WEBCFG(PLAIN_PORT).num(), WEBCFG(TLS_PORT).num());
 		printf("Config path: %s\n", AppUtil::getPath(AppUtil::PATH_USER_CONFIG).c_str());
 		printf("Web resources path: %s\n", wsm->getHttpManager().getFileServer().getResourcePath().c_str());
@@ -107,7 +107,7 @@ bool Client::startup(const dcpp::StartupParams& aStartupParams) {
 	auto wsm = webserver::WebServerManager::getInstance();
 	if (!wsm->load(webErrorF) || !wsm->hasUsers()) {
 		webserver::WebServerManager::deleteInstance();
-		printf("%s\n", "No valid configuration found. Run the application with --configure parameter to set up initial configuration.");
+		printf("No valid configuration found (using config directory %s). Run the application with --configure parameter to set up initial configuration.\n", AppUtil::getPath(AppUtil::PATH_USER_CONFIG).c_str());
 		return false;
 	}
 
@@ -204,4 +204,8 @@ void Client::on(ClientManagerListener::ClientCreated, const ClientPtr& aClient)
 	aClient->connect();
 }
 
+void Client::on(ClientManagerListener::ClientRedirected, const ClientPtr& /*aOldClient*/, const ClientPtr& aNewClient) noexcept {
+	aNewClient->connect();
+}
+
 }
