@@ -263,7 +263,7 @@ static void runDaemon(const dcpp::StartupParams& aStartupParams) {
 }
 
 static void runConsole(const dcpp::StartupParams& aStartupParams) {
-	printf("Starting.\n"); fflush(stdout);
+	printf("Initializing."); fflush(stdout);
 
 	savePid(static_cast<int>(getpid()));
 
@@ -273,6 +273,8 @@ static void runConsole(const dcpp::StartupParams& aStartupParams) {
 
 		init();
 
+		printf(".\n"); fflush(stdout);
+
 		client->run(aStartupParams);
 
 		client.reset();
